aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--docs/BUILD.gn3
-rw-r--r--docs/automated_analysis.rst4
-rw-r--r--pw_assert/assert_backend_compile_test.cc3
-rw-r--r--pw_blob_store/flat_file_system_entry.cc2
-rw-r--r--pw_boot_cortex_m/basic_cortex_m.ld2
-rw-r--r--pw_build/bazel_internal/linker_script.ld2
-rw-r--r--pw_build/copy_from_cipd.gni2
-rw-r--r--pw_build/docs.rst2
-rw-r--r--pw_build/pigweed.bzl4
-rw-r--r--pw_build/pigweed.cmake6
-rwxr-xr-xpw_build/py/pw_build/python_runner.py6
-rw-r--r--pw_build/python_dist.gni2
-rw-r--r--pw_console/py/pw_console/log_store.py4
-rw-r--r--pw_containers/intrusive_list_test.cc6
-rw-r--r--pw_cpu_exception_cortex_m/BUILD.gn2
-rw-r--r--pw_cpu_exception_cortex_m/CMakeLists.txt2
-rw-r--r--pw_cpu_exception_cortex_m/pw_cpu_exception_cortex_m_private/cortex_m_constants.h2
-rw-r--r--pw_docgen/py/pw_docgen/docgen.py2
-rwxr-xr-xpw_doctor/py/pw_doctor/doctor.py2
-rw-r--r--pw_env_setup/bazel/cipd_setup/internal/cipd_internal.bzl4
-rw-r--r--pw_function/function_test.cc2
-rw-r--r--pw_fuzzer/fuzzer.bzl2
-rw-r--r--pw_fuzzer/fuzzer.gni2
-rw-r--r--pw_fuzzer/pw_fuzzer_disabled.cc2
-rw-r--r--pw_hex_dump/public/pw_hex_dump/hex_dump.h2
-rw-r--r--pw_i2c/address_test.cc6
-rw-r--r--pw_log/basic_log_test.cc6
-rw-r--r--pw_log/glog_adapter_test.cc2
-rw-r--r--pw_log/public/pw_log/options.h2
-rw-r--r--pw_log_basic/public/pw_log_basic/log_basic.h3
-rw-r--r--pw_persistent_ram/public/pw_persistent_ram/persistent.h2
-rw-r--r--pw_preprocessor/public/pw_preprocessor/arch.h4
-rw-r--r--pw_preprocessor/public/pw_preprocessor/compiler.h2
-rw-r--r--pw_presubmit/py/pw_presubmit/build.py2
-rwxr-xr-xpw_presubmit/py/pw_presubmit/pigweed_presubmit.py4
-rw-r--r--pw_protobuf/encoder_fuzzer.cc2
-rw-r--r--pw_protobuf/stream_decoder.cc4
-rw-r--r--pw_protobuf_compiler/pw_nanopb_cc_library.bzl2
-rw-r--r--pw_protobuf_compiler/pw_proto_library.bzl4
-rw-r--r--pw_ring_buffer/prefixed_entry_ring_buffer.cc6
-rw-r--r--pw_ring_buffer/public/pw_ring_buffer/prefixed_entry_ring_buffer.h11
-rw-r--r--pw_rpc/BUILD.bazel2
-rw-r--r--pw_rpc/nanopb/BUILD.bazel2
-rw-r--r--pw_rpc/nanopb/public/pw_rpc/nanopb/client_testing.h2
-rw-r--r--pw_rpc/public/pw_rpc/channel.h2
-rw-r--r--pw_rpc/pwpb/BUILD.bazel2
-rw-r--r--pw_rpc/pwpb/public/pw_rpc/pwpb/client_testing.h2
-rw-r--r--pw_rpc/pwpb/public/pw_rpc/pwpb/internal/method.h6
-rw-r--r--pw_rpc/py/pw_rpc/testing.py2
-rw-r--r--pw_rpc/raw/public/pw_rpc/raw/client_testing.h2
-rw-r--r--pw_software_update/bundled_update.proto2
-rw-r--r--pw_software_update/public/pw_software_update/bundled_update_backend.h2
-rw-r--r--pw_software_update/py/remote_sign_test.py2
-rw-r--r--pw_sync_baremetal/public/pw_sync_baremetal/interrupt_spin_lock_inline.h2
-rw-r--r--pw_system/docs.rst2
-rw-r--r--pw_system/work_queue.cc2
-rw-r--r--pw_thread/snapshot.cc2
-rw-r--r--pw_thread_freertos/snapshot.cc2
-rw-r--r--pw_tls_client/BUILD.gn4
-rw-r--r--pw_tokenizer/options.proto2
-rw-r--r--pw_toolchain/generate_toolchain.gni2
-rw-r--r--pw_toolchain/host_clang/toolchain.cmake2
-rw-r--r--pw_toolchain/host_clang/toolchains.gni2
-rw-r--r--pw_toolchain/host_gcc/toolchain.cmake2
-rw-r--r--pw_trace_tokenized/trace_buffer_log_test.cc4
-rw-r--r--pw_transfer/BUILD.gn2
-rw-r--r--pw_unit_test/static_library_support_test.cc2
-rw-r--r--targets/emcraft_sf2_som/BUILD.gn4
-rw-r--r--targets/emcraft_sf2_som/emcraft_sf2_som_mddr_debug.ld2
-rw-r--r--targets/stm32f429i_disc1/target_toolchains.gni2
-rw-r--r--targets/stm32f429i_disc1_stm32cube/BUILD.gn2
71 files changed, 104 insertions, 100 deletions
diff --git a/docs/BUILD.gn b/docs/BUILD.gn
index 5ddab0c80..026171f2d 100644
--- a/docs/BUILD.gn
+++ b/docs/BUILD.gn
@@ -28,7 +28,8 @@ pw_doc_group("core_docs") {
"images/pw_watch_test_demo.gif",
"images/stm32f429i-disc1_connected.jpg",
- # TODO(pwbug/368): This should be in the pw_doc_gen target instead of here.
+ # TODO(b/235348007): This should be in the pw_doc_gen target instead of
+ # here.
"_static/css/pigweed.css",
]
sources = [
diff --git a/docs/automated_analysis.rst b/docs/automated_analysis.rst
index 23a31780d..34594bd0d 100644
--- a/docs/automated_analysis.rst
+++ b/docs/automated_analysis.rst
@@ -106,8 +106,8 @@ described in this section. For more detail about these sanitizers, see the
We use the default ``-fsanitize=undefined`` option.
.. note::
- Pigweed does not currently support msan. See https://bugs.pigweed.dev/560
- for details.
+ Pigweed does not currently support msan. See
+ https://issuetracker.google.com/234876100 for details.
The exact configurations we use for these sanitizers are in
`pw_toolchain/host_clang/BUILD.gn <https://cs.opensource.google/pigweed/pigweed/+/main:pw_toolchain/host_clang/BUILD.gn>`_.
diff --git a/pw_assert/assert_backend_compile_test.cc b/pw_assert/assert_backend_compile_test.cc
index 96f17e432..888499984 100644
--- a/pw_assert/assert_backend_compile_test.cc
+++ b/pw_assert/assert_backend_compile_test.cc
@@ -33,7 +33,8 @@
// the test has failed. Obviously manually verifying these is a pain
// and so this is not a suitable test for production.
//
-// TODO(pwbug/88): Add verification of the actually recorded asserts statements.
+// TODO(b/235289499): Add verification of the actually recorded asserts
+// statements.
#include "gtest/gtest.h"
#include "pw_assert/short.h"
diff --git a/pw_blob_store/flat_file_system_entry.cc b/pw_blob_store/flat_file_system_entry.cc
index 76d2fc892..c1bc594db 100644
--- a/pw_blob_store/flat_file_system_entry.cc
+++ b/pw_blob_store/flat_file_system_entry.cc
@@ -80,7 +80,7 @@ size_t FlatFileSystemBlobStoreEntry::SizeBytes() {
return reader.ConservativeReadLimit();
}
-// TODO(pwbug/488): This file can be deleted even though it is read-only.
+// TODO(b/234888404): This file can be deleted even though it is read-only.
// This type of behavior should be possible to express via the FileSystem RPC
// service.
Status FlatFileSystemBlobStoreEntry::Delete() {
diff --git a/pw_boot_cortex_m/basic_cortex_m.ld b/pw_boot_cortex_m/basic_cortex_m.ld
index a14a20423..0ce982373 100644
--- a/pw_boot_cortex_m/basic_cortex_m.ld
+++ b/pw_boot_cortex_m/basic_cortex_m.ld
@@ -65,7 +65,7 @@ ENTRY(pw_boot_Entry)
MEMORY
{
- /* TODO(pwbug/57): Make it possible for projects to freely customize
+ /* TODO(b/234892223): Make it possible for projects to freely customize
* memory regions.
*/
diff --git a/pw_build/bazel_internal/linker_script.ld b/pw_build/bazel_internal/linker_script.ld
index 7c3169e7b..bd6609931 100644
--- a/pw_build/bazel_internal/linker_script.ld
+++ b/pw_build/bazel_internal/linker_script.ld
@@ -31,7 +31,7 @@ ENTRY(pw_boot_Entry)
MEMORY
{
- /* TODO(pwbug/57): Make it possible for projects to freely customize
+ /* TODO(b/234892223): Make it possible for projects to freely customize
* memory regions.
*/
diff --git a/pw_build/copy_from_cipd.gni b/pw_build/copy_from_cipd.gni
index aff8afac4..e8693d76a 100644
--- a/pw_build/copy_from_cipd.gni
+++ b/pw_build/copy_from_cipd.gni
@@ -71,7 +71,7 @@ template("pw_cipd_static_library") {
# might work but is redundant, so serialize calls.
pool = "$dir_pw_build/pool:copy_from_cipd($default_toolchain)"
- # TODO(pwbug/335): This should somehow track the actual .a for changes as
+ # TODO(b/234884827): This should somehow track the actual .a for changes as
# well.
inputs = [ invoker.manifest ]
outputs = [ _out_file ]
diff --git a/pw_build/docs.rst b/pw_build/docs.rst
index b55ea5b09..3c10b0267 100644
--- a/pw_build/docs.rst
+++ b/pw_build/docs.rst
@@ -295,7 +295,7 @@ about converting them to files.
.. note::
We intend to replace these expressions with native GN features when possible.
- See `pwbug/347 <http://bugs.pigweed.dev/347>`_.
+ See `b/234886742 <http://issuetracker.google.com/234886742>`_.
The following expressions are supported:
diff --git a/pw_build/pigweed.bzl b/pw_build/pigweed.bzl
index f6410d47a..bfca992e4 100644
--- a/pw_build/pigweed.bzl
+++ b/pw_build/pigweed.bzl
@@ -22,7 +22,7 @@ load(
def pw_cc_binary(**kwargs):
kwargs["deps"] = kwargs.get("deps", [])
- # TODO(pwbug/440): Remove this implicit dependency once we have a better
+ # TODO(b/234877642): Remove this implicit dependency once we have a better
# way to handle the facades without introducing a circular dependency into
# the build.
if not _has_pw_assert_dep(kwargs["deps"]):
@@ -36,7 +36,7 @@ def pw_cc_test(**kwargs):
kwargs["deps"] = kwargs.get("deps", []) + \
["@pigweed//pw_unit_test:simple_printing_main"]
- # TODO(pwbug/440): Remove this implicit dependency once we have a better
+ # TODO(b/234877642): Remove this implicit dependency once we have a better
# way to handle the facades without introducing a circular dependency into
# the build.
if not _has_pw_assert_dep(kwargs["deps"]):
diff --git a/pw_build/pigweed.cmake b/pw_build/pigweed.cmake
index 3ef02c4ab..bac7d05d3 100644
--- a/pw_build/pigweed.cmake
+++ b/pw_build/pigweed.cmake
@@ -371,7 +371,7 @@ function(pw_add_module_library NAME)
HEADERS
${arg_HEADERS}
PUBLIC_DEPS
- # TODO(pwbug/232141950): Apply compilation options that affect ABI
+ # TODO(b/232141950): Apply compilation options that affect ABI
# globally in the CMake build instead of injecting them into libraries.
pw_build
${arg_PUBLIC_DEPS}
@@ -396,13 +396,13 @@ function(pw_add_module_library NAME)
${arg_PRIVATE_LINK_OPTIONS}
)
- # TODO(pwbug/601): Deprecate this legacy implicit PUBLIC_INCLUDES.
+ # TODO(b/235273746): Deprecate this legacy implicit PUBLIC_INCLUDES.
if("${arg_PUBLIC_INCLUDES}" STREQUAL "")
target_include_directories("${NAME}" ${public_or_interface} public)
endif("${arg_PUBLIC_INCLUDES}" STREQUAL "")
if(NOT "${arg_IMPLEMENTS_FACADES}" STREQUAL "")
- # TODO(pwbug/601): Deprecate this legacy implicit PUBLIC_INCLUDES.
+ # TODO(b/235273746): Deprecate this legacy implicit PUBLIC_INCLUDES.
if("${arg_PUBLIC_INCLUDES}" STREQUAL "")
target_include_directories(
"${NAME}" ${public_or_interface} public_overrides)
diff --git a/pw_build/py/pw_build/python_runner.py b/pw_build/py/pw_build/python_runner.py
index 82a9b8087..d1e29a9a3 100755
--- a/pw_build/py/pw_build/python_runner.py
+++ b/pw_build/py/pw_build/python_runner.py
@@ -429,7 +429,7 @@ def _target_objects(paths: GnPaths, expr: _Expression) -> _Actions:
yield _ArgAction.EMIT_NEW, str(obj)
-# TODO(pwbug/347): Replace expressions with native GN features when possible.
+# TODO(b/234886742): Replace expressions with native GN features when possible.
_FUNCTIONS: Dict['str', Callable[[GnPaths, _Expression], _Actions]] = {
'TARGET_FILE': _target_file,
'TARGET_FILE_IF_EXISTS': _target_file_if_exists,
@@ -662,8 +662,8 @@ def main( # pylint: disable=too-many-arguments,too-many-branches,too-many-local
if working_directory:
run_args['cwd'] = working_directory
- # TODO(pwbug/666): Deprecate the --lockfile option as part of the Python GN
- # template refactor.
+ # TODO(b/235239674): Deprecate the --lockfile option as part of the Python
+ # GN template refactor.
if lockfile:
try:
acquire_lock(lockfile, is_pip_command)
diff --git a/pw_build/python_dist.gni b/pw_build/python_dist.gni
index 8d32956fc..0bbcdad04 100644
--- a/pw_build/python_dist.gni
+++ b/pw_build/python_dist.gni
@@ -134,7 +134,7 @@ template("pw_python_zip_with_setup") {
output = _zip_path
- # TODO(pwbug/634): Remove the plumbing-through of invoker's public_deps.
+ # TODO(b/235245034): Remove the plumbing-through of invoker's public_deps.
public_deps = _public_deps + [ ":${_outer_name}.wheels" ]
}
}
diff --git a/pw_console/py/pw_console/log_store.py b/pw_console/py/pw_console/log_store.py
index ed6ebb447..06096e87a 100644
--- a/pw_console/py/pw_console/log_store.py
+++ b/pw_console/py/pw_console/log_store.py
@@ -216,8 +216,8 @@ class LogStore(logging.Handler):
self.channel_counts[record.name] = self.channel_counts.get(
record.name, 0) + 1
- # TODO(pwbug/614): Revisit calculating prefix widths automatically when
- # line wrapping indentation is supported.
+ # TODO(b/235271486): Revisit calculating prefix widths automatically
+ # when line wrapping indentation is supported.
# Set the prefix width to 0
self.channel_formatted_prefix_widths[record.name] = 0
diff --git a/pw_containers/intrusive_list_test.cc b/pw_containers/intrusive_list_test.cc
index 2681cc0fb..7e39cf438 100644
--- a/pw_containers/intrusive_list_test.cc
+++ b/pw_containers/intrusive_list_test.cc
@@ -426,7 +426,7 @@ TEST(IntrusiveList, CompareConstAndNonConstIterator_CompilationFails) {
#endif
-// TODO(pwbug/47): These tests should fail to compile, enable when no-compile
+// TODO(b/234882063): These tests should fail to compile, enable when no-compile
// tests are set up in Pigweed.
#if defined(PW_COMPILE_FAIL_TEST_cannot_modify_through_const_iterator)
TEST(IntrusiveList, ConstIteratorModify) {
@@ -447,7 +447,7 @@ TEST(IntrusiveList, ConstIteratorModify) {
}
#endif // Compile failure test
-// TODO(pwbug/88): These tests should trigger a CHECK failure. This requires
+// TODO(b/235289499): These tests should trigger a CHECK failure. This requires
// using a testing version of pw_assert.
#define TESTING_CHECK_FAILURES_IS_SUPPORTED 0
#if TESTING_CHECK_FAILURES_IS_SUPPORTED
@@ -675,7 +675,7 @@ TEST(InstrusiveList, ListOfDerivedClassItems) {
EXPECT_EQ(1u, derived_from_compatible_item_type.size());
-// TODO(pwbug/47): Make these proper automated compilation failure tests.
+// TODO(b/234882063): Make these proper automated compilation failure tests.
#if defined(PW_COMPILE_FAIL_TEST_cannot_add_base_class_to_derived_class_list)
TestItem item2;
derived_from_compatible_item_type.push_front(item2);
diff --git a/pw_cpu_exception_cortex_m/BUILD.gn b/pw_cpu_exception_cortex_m/BUILD.gn
index 226a4da7f..2fa43f2ed 100644
--- a/pw_cpu_exception_cortex_m/BUILD.gn
+++ b/pw_cpu_exception_cortex_m/BUILD.gn
@@ -210,7 +210,7 @@ pw_test_group("tests") {
tests = [ ":cpu_exception_entry_test" ]
}
-# TODO(pwbug/583): Add ARMv8-M mainline coverage.
+# TODO(b/234888156): Add ARMv8-M mainline coverage.
pw_test("cpu_exception_entry_test") {
enable_if = pw_cpu_exception_ENTRY_BACKEND ==
"$dir_pw_cpu_exception_cortex_m:cpu_exception"
diff --git a/pw_cpu_exception_cortex_m/CMakeLists.txt b/pw_cpu_exception_cortex_m/CMakeLists.txt
index 32e6dfdd6..4897d1a59 100644
--- a/pw_cpu_exception_cortex_m/CMakeLists.txt
+++ b/pw_cpu_exception_cortex_m/CMakeLists.txt
@@ -135,7 +135,7 @@ pw_add_module_library(pw_cpu_exception_cortex_m.constants
pw_cpu_exception_cortex_m_private/cortex_m_constants.h
)
-# TODO(pwbug/583): Add ARMv8-M mainline coverage.
+# TODO(b/234888156): Add ARMv8-M mainline coverage.
if("${pw_cpu_exception.entry_BACKEND}" STREQUAL
"pw_cpu_exception_cortex_m.cpu_exception")
pw_add_test(pw_cpu_exception_cortex_m.cpu_exception_entry_test
diff --git a/pw_cpu_exception_cortex_m/pw_cpu_exception_cortex_m_private/cortex_m_constants.h b/pw_cpu_exception_cortex_m/pw_cpu_exception_cortex_m_private/cortex_m_constants.h
index a47d67251..255057669 100644
--- a/pw_cpu_exception_cortex_m/pw_cpu_exception_cortex_m_private/cortex_m_constants.h
+++ b/pw_cpu_exception_cortex_m/pw_cpu_exception_cortex_m_private/cortex_m_constants.h
@@ -85,7 +85,7 @@ constexpr uint32_t kXpsrIpsrMask = 0b1'1111'1111;
constexpr uint32_t kControlThreadModeStackMask = 0x1u << 1; // 0=MSP, 1=PSP
// Memory mapped registers. (ARMv7-M Section B3.2.2, Table B3-4)
-// TODO(pwbug/316): Only some of these are supported on ARMv6-M.
+// TODO(b/234891073): Only some of these are supported on ARMv6-M.
inline volatile uint32_t& cortex_m_cfsr =
*reinterpret_cast<volatile uint32_t*>(0xE000ED28u);
inline volatile uint32_t& cortex_m_mmfar =
diff --git a/pw_docgen/py/pw_docgen/docgen.py b/pw_docgen/py/pw_docgen/docgen.py
index 7b65e7754..27303a07b 100644
--- a/pw_docgen/py/pw_docgen/docgen.py
+++ b/pw_docgen/py/pw_docgen/docgen.py
@@ -128,7 +128,7 @@ def main() -> int:
if os.path.exists(args.sphinx_build_dir):
shutil.rmtree(args.sphinx_build_dir)
- # TODO(pwbug/164): Printing the header causes unicode problems on Windows.
+ # TODO(b/235349854): Printing the header causes unicode problems on Windows.
# Disabled for now; re-enable once the root issue is fixed.
# print(SCRIPT_HEADER)
copy_doc_tree(args)
diff --git a/pw_doctor/py/pw_doctor/doctor.py b/pw_doctor/py/pw_doctor/doctor.py
index fea164d4a..d32f48693 100755
--- a/pw_doctor/py/pw_doctor/doctor.py
+++ b/pw_doctor/py/pw_doctor/doctor.py
@@ -432,7 +432,7 @@ def run_doctor(strict=False, checks=None):
"Your environment setup has completed, but something isn't right "
'and some things may not work correctly. You may continue with '
'development, but please seek support at '
- 'https://bugs.pigweed.dev/ or by reaching out to your team.')
+ 'https://bugs.pigweed.dev/new or by reaching out to your team.')
else:
doctor.log.info('Environment passes all checks!')
return len(doctor.failures)
diff --git a/pw_env_setup/bazel/cipd_setup/internal/cipd_internal.bzl b/pw_env_setup/bazel/cipd_setup/internal/cipd_internal.bzl
index bbd2c95e8..6bbc06585 100644
--- a/pw_env_setup/bazel/cipd_setup/internal/cipd_internal.bzl
+++ b/pw_env_setup/bazel/cipd_setup/internal/cipd_internal.bzl
@@ -43,7 +43,7 @@ def platform_normalized(rctx):
else:
fail("Could not normalize os:", rctx.os.name)
-# TODO(pwbug/388): Enable unused variable check.
+# TODO(b/234879770): Enable unused variable check.
# buildifier: disable=unused-variable
def arch_normalized(rctx):
"""Normalizes the architecture string to match CIPDs naming system.
@@ -55,7 +55,7 @@ def arch_normalized(rctx):
str: Normalized architecture.
"""
- # TODO(pwbug/388): Find a way to get host architecture information from a
+ # TODO(b/234879770): Find a way to get host architecture information from a
# repository context.
return "amd64"
diff --git a/pw_function/function_test.cc b/pw_function/function_test.cc
index 8ba01d93e..c6fd122b7 100644
--- a/pw_function/function_test.cc
+++ b/pw_function/function_test.cc
@@ -20,7 +20,7 @@
namespace pw {
namespace {
-// TODO(pwbug/47): Convert this to a compilation failure test.
+// TODO(b/234882063): Convert this to a compilation failure test.
#if defined(PW_COMPILE_FAIL_TEST_CannotInstantiateWithNonFunction)
[[maybe_unused]] Function<int> function_pointer;
diff --git a/pw_fuzzer/fuzzer.bzl b/pw_fuzzer/fuzzer.bzl
index 2c82feea6..7826fa52e 100644
--- a/pw_fuzzer/fuzzer.bzl
+++ b/pw_fuzzer/fuzzer.bzl
@@ -21,7 +21,7 @@ load(
)
def pw_cc_fuzz_test(**kwargs):
- # TODO(pwbug/440): Remove this implicit dependency once we have a better
+ # TODO(b/234877642): Remove this implicit dependency once we have a better
# way to handle the facades without introducing a circular dependency into
# the build.
if not _has_pw_assert_dep(kwargs["deps"]):
diff --git a/pw_fuzzer/fuzzer.gni b/pw_fuzzer/fuzzer.gni
index 9bcf50e02..beb3a1c5d 100644
--- a/pw_fuzzer/fuzzer.gni
+++ b/pw_fuzzer/fuzzer.gni
@@ -92,7 +92,7 @@ template("pw_fuzzer") {
} else {
# Build a unit test that exercise the fuzz target function.
pw_test(target_name) {
- # TODO(pwbug/195): Re-enable when there's better configurability for
+ # TODO(b/234891784): Re-enable when there's better configurability for
# on-device fuzz testing.
enable_if = false
sources = []
diff --git a/pw_fuzzer/pw_fuzzer_disabled.cc b/pw_fuzzer/pw_fuzzer_disabled.cc
index 7d01cff24..5b47a1073 100644
--- a/pw_fuzzer/pw_fuzzer_disabled.cc
+++ b/pw_fuzzer/pw_fuzzer_disabled.cc
@@ -32,4 +32,4 @@ TEST(Fuzzer, EmptyInput) {
EXPECT_EQ(LLVMFuzzerTestOneInput(nullptr, 0), 0);
}
-// TODO(pwbug/178): Add support for testing a seed corpus.
+// TODO(b/234883542): Add support for testing a seed corpus.
diff --git a/pw_hex_dump/public/pw_hex_dump/hex_dump.h b/pw_hex_dump/public/pw_hex_dump/hex_dump.h
index 9befbcc35..61ab7f0fb 100644
--- a/pw_hex_dump/public/pw_hex_dump/hex_dump.h
+++ b/pw_hex_dump/public/pw_hex_dump/hex_dump.h
@@ -107,7 +107,7 @@ class FormattedHexDumper {
.IgnoreError(); // TODO(pwbug/387): Handle Status properly
}
- // TODO(pwbug/218): Add iterator support.
+ // TODO(b/234892215): Add iterator support.
// Set the destination buffer that the hex dumper will write to line-by-line.
//
diff --git a/pw_i2c/address_test.cc b/pw_i2c/address_test.cc
index 71ac11fe7..0d3a90e83 100644
--- a/pw_i2c/address_test.cc
+++ b/pw_i2c/address_test.cc
@@ -39,10 +39,10 @@ TEST(Address, TenBitRuntimeChecked) {
EXPECT_EQ(ten_bit.GetTenBit(), Address::kMaxTenBitAddress);
}
-// TODO(pwbug/88): Verify assert behaviour when trying to get a 7bit address out
-// of a 10bit address.
+// TODO(b/235289499): Verify assert behaviour when trying to get a 7bit address
+// out of a 10bit address.
-// TODO(pwbug/47): Add tests to ensure the constexpr constructors fail to
+// TODO(b/234882063): Add tests to ensure the constexpr constructors fail to
// compile with invalid addresses once no-copmile tests are set up in Pigweed.
} // namespace pw::i2c
diff --git a/pw_log/basic_log_test.cc b/pw_log/basic_log_test.cc
index a7042a8c1..a4c08f9dc 100644
--- a/pw_log/basic_log_test.cc
+++ b/pw_log/basic_log_test.cc
@@ -16,7 +16,7 @@
// compile the constructs promised by the logging facade; and that when run,
// there is no crash.
//
-// TODO(pwbug/88): Add verification of the actually logged statements.
+// TODO(b/235289499): Add verification of the actually logged statements.
// clang-format off
#define PW_LOG_MODULE_NAME "TST"
@@ -28,8 +28,8 @@
#include "gtest/gtest.h"
-// TODO(pwbug/86): Test unsigned integer logging (32 and 64 bit); test pointer
-// logging.
+// TODO(b/235291136): Test unsigned integer logging (32 and 64 bit); test
+// pointer logging.
void LoggingFromFunction() { PW_LOG_INFO("From a function!"); }
diff --git a/pw_log/glog_adapter_test.cc b/pw_log/glog_adapter_test.cc
index f8265031f..d6691cea0 100644
--- a/pw_log/glog_adapter_test.cc
+++ b/pw_log/glog_adapter_test.cc
@@ -11,7 +11,7 @@
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations under
// the License.
-// TODO(pwbug/88): Add verification of the actually logged statements.
+// TODO(b/235289499): Add verification of the actually logged statements.
// clang-format off
#define PW_LOG_MODULE_NAME "TST"
diff --git a/pw_log/public/pw_log/options.h b/pw_log/public/pw_log/options.h
index 2d20bd6d6..ad1b28abe 100644
--- a/pw_log/public/pw_log/options.h
+++ b/pw_log/public/pw_log/options.h
@@ -68,7 +68,7 @@
#endif // PW_LOG_FLAGS
// DEPRECATED: Use PW_LOG_FLAGS.
-// TODO(pwbug/561): Remove this macro after migration.
+// TODO(b/234876701): Remove this macro after migration.
#ifndef PW_LOG_DEFAULT_FLAGS
#define PW_LOG_DEFAULT_FLAGS PW_LOG_FLAGS
#endif // PW_LOG_DEFAULT_FLAGS
diff --git a/pw_log_basic/public/pw_log_basic/log_basic.h b/pw_log_basic/public/pw_log_basic/log_basic.h
index d16ef0bb1..93fd2f136 100644
--- a/pw_log_basic/public/pw_log_basic/log_basic.h
+++ b/pw_log_basic/public/pw_log_basic/log_basic.h
@@ -38,7 +38,8 @@ PW_EXTERN_C_END
// arguments. Additionally, the use of the __FUNC__ macro adds a static const
// char[] variable inside functions with a log.
//
-// TODO(pwbug/87): Reconsider the naming of this module when more is in place.
+// TODO(b/235289435): Reconsider the naming of this module when more is in
+// place.
#define PW_HANDLE_LOG(level, flags, message, ...) \
do { \
pw_Log((level), \
diff --git a/pw_persistent_ram/public/pw_persistent_ram/persistent.h b/pw_persistent_ram/public/pw_persistent_ram/persistent.h
index 8414f4377..eb8e5a76e 100644
--- a/pw_persistent_ram/public/pw_persistent_ram/persistent.h
+++ b/pw_persistent_ram/public/pw_persistent_ram/persistent.h
@@ -48,7 +48,7 @@ PW_MODIFY_DIAGNOSTIC_GCC(ignored, "-Wmaybe-uninitialized");
// WARNING: Unlike a DoubleBufferedPersistent, a Persistent will be lost if a
// write/set operation is interrupted or otherwise not completed.
//
-// TODO(pwbug/348): Consider a different integrity check implementation which
+// TODO(b/235277454): Consider a different integrity check implementation which
// does not use a 512B lookup table.
template <typename T>
class Persistent {
diff --git a/pw_preprocessor/public/pw_preprocessor/arch.h b/pw_preprocessor/public/pw_preprocessor/arch.h
index 45b7ff42e..676a386c2 100644
--- a/pw_preprocessor/public/pw_preprocessor/arch.h
+++ b/pw_preprocessor/public/pw_preprocessor/arch.h
@@ -13,10 +13,10 @@
// the License.
#pragma once
-// TODO(pwbug/594): arch.h should be refactored out of pw_preprocessor as the
+// TODO(b/234887943): arch.h should be refactored out of pw_preprocessor as the
// scope is outside of the module. The intended scope of arch.h is only to
// provide architecture targeting and not any added utilities and capabilities.
-// Perhaps it should be placed under pw_compiler along with pwbug/593, e.g.
+// Perhaps it should be placed under pw_compiler along with b/234877280, e.g.
// pw_compiler/arch.h?
// Regardless, the arch defines should likely move to a trait system in Pigweed
// before making them public defines for others to use.
diff --git a/pw_preprocessor/public/pw_preprocessor/compiler.h b/pw_preprocessor/public/pw_preprocessor/compiler.h
index 690a061b9..44c2fa9f1 100644
--- a/pw_preprocessor/public/pw_preprocessor/compiler.h
+++ b/pw_preprocessor/public/pw_preprocessor/compiler.h
@@ -18,7 +18,7 @@
#include <assert.h>
-// TODO(pwbug/593): compiler.h should be refactored out of pw_preprocessor as
+// TODO(b/234877280): compiler.h should be refactored out of pw_preprocessor as
// the scope is outside of the module. Perhaps it should be split up and placed
// under pw_compiler, e.g. pw_compiler/attributes.h & pw_compiler/builtins.h.
diff --git a/pw_presubmit/py/pw_presubmit/build.py b/pw_presubmit/py/pw_presubmit/build.py
index 1c5dc75c5..9b8882835 100644
--- a/pw_presubmit/py/pw_presubmit/build.py
+++ b/pw_presubmit/py/pw_presubmit/build.py
@@ -315,7 +315,7 @@ def check_builds_for_files(
for path in (p for p in files
if p.suffix in bazel_extensions_to_check):
if path not in bazel_builds:
- # TODO(pwbug/176) Replace this workaround for fuzzers.
+ # TODO(b/234883555) Replace this workaround for fuzzers.
if 'fuzz' not in str(path):
missing['Bazel'].append(path)
diff --git a/pw_presubmit/py/pw_presubmit/pigweed_presubmit.py b/pw_presubmit/py/pw_presubmit/pigweed_presubmit.py
index dea564182..b290e2bd4 100755
--- a/pw_presubmit/py/pw_presubmit/pigweed_presubmit.py
+++ b/pw_presubmit/py/pw_presubmit/pigweed_presubmit.py
@@ -785,7 +785,7 @@ OTHER_CHECKS = (
# Build that attempts to duplicate the build OSS-Fuzz does. Currently
# failing.
oss_fuzz_build,
- # TODO(pwbug/346): Enable all Bazel tests when they're fixed.
+ # TODO(b/235277910): Enable all Bazel tests when they're fixed.
bazel_test,
cmake_clang,
cmake_gcc,
@@ -828,7 +828,7 @@ LINTFORMAT = (
QUICK = (
_LINTFORMAT,
gn_quick_build_check,
- # TODO(pwbug/141): Re-enable CMake and Bazel for Mac after we have fixed the
+ # TODO(b/34884583): Re-enable CMake and Bazel for Mac after we have fixed
# the clang issues. The problem is that all clang++ invocations need the
# two extra flags: "-nostdc++" and "${clang_prefix}/../lib/libc++.a".
cmake_clang if sys.platform != 'darwin' else (),
diff --git a/pw_protobuf/encoder_fuzzer.cc b/pw_protobuf/encoder_fuzzer.cc
index 2a848df2d..7f05783f8 100644
--- a/pw_protobuf/encoder_fuzzer.cc
+++ b/pw_protobuf/encoder_fuzzer.cc
@@ -58,7 +58,7 @@ enum FieldType : uint8_t {
kMaxValue = kPush,
};
-// TODO(pwbug/181): Move this to pw_fuzzer/fuzzed_data_provider.h
+// TODO(b/235289495): Move this to pw_fuzzer/fuzzed_data_provider.h
// Uses the given |provider| to pick and return a number between 0 and the
// maximum numbers of T that can be generated from the remaining input data.
diff --git a/pw_protobuf/stream_decoder.cc b/pw_protobuf/stream_decoder.cc
index 5873b5f7d..2a93ec688 100644
--- a/pw_protobuf/stream_decoder.cc
+++ b/pw_protobuf/stream_decoder.cc
@@ -518,12 +518,12 @@ Status StreamDecoder::Read(span<std::byte> message,
while (Next().ok()) {
// Find the field in the table,
- // TODO(pwbug/650): Finding the field can be made more efficient.
+ // TODO(b/234876102): Finding the field can be made more efficient.
const auto field =
std::find(table.begin(), table.end(), current_field_.field_number());
if (field == table.end()) {
// If the field is not found, skip to the next one.
- // TODO(pwbug/659): Provide a way to allow the caller to inspect unknown
+ // TODO(b/234873295): Provide a way to allow the caller to inspect unknown
// fields, and serialize them back out later.
continue;
}
diff --git a/pw_protobuf_compiler/pw_nanopb_cc_library.bzl b/pw_protobuf_compiler/pw_nanopb_cc_library.bzl
index a5ae2d26a..c2bda47c3 100644
--- a/pw_protobuf_compiler/pw_nanopb_cc_library.bzl
+++ b/pw_protobuf_compiler/pw_nanopb_cc_library.bzl
@@ -16,7 +16,7 @@
Nanopb C++ library generating targets.
"""
-# TODO(pwbug/621) Enable unused variable check.
+# TODO(b/234873954) Enable unused variable check.
# buildifier: disable=unused-variable
def pw_nanopb_cc_library(
name,
diff --git a/pw_ring_buffer/prefixed_entry_ring_buffer.cc b/pw_ring_buffer/prefixed_entry_ring_buffer.cc
index 5a146a45c..e2f7f7b8d 100644
--- a/pw_ring_buffer/prefixed_entry_ring_buffer.cc
+++ b/pw_ring_buffer/prefixed_entry_ring_buffer.cc
@@ -173,9 +173,9 @@ Status PrefixedEntryRingBufferMulti::InternalPeekFrontPreamble(
return OkStatus();
}
-// TODO(pwbug/339): Consider whether this internal templating is required, or if
-// we can simply promote GetOutput to a static function and remove the template.
-// T should be similar to Status (*read_output)(span<const byte>)
+// TODO(b/235351046): Consider whether this internal templating is required, or
+// if we can simply promote GetOutput to a static function and remove the
+// template. T should be similar to Status (*read_output)(span<const byte>)
template <typename T>
Status PrefixedEntryRingBufferMulti::InternalRead(
const Reader& reader,
diff --git a/pw_ring_buffer/public/pw_ring_buffer/prefixed_entry_ring_buffer.h b/pw_ring_buffer/public/pw_ring_buffer/prefixed_entry_ring_buffer.h
index fcb96fcde..654bd57dc 100644
--- a/pw_ring_buffer/public/pw_ring_buffer/prefixed_entry_ring_buffer.h
+++ b/pw_ring_buffer/public/pw_ring_buffer/prefixed_entry_ring_buffer.h
@@ -63,7 +63,7 @@ class PrefixedEntryRingBufferMulti {
public:
constexpr Reader() : buffer_(nullptr), read_idx_(0), entry_count_(0) {}
- // TODO(pwbug/344): Add locking to the internal functions. Who owns the
+ // TODO(b/235351035): Add locking to the internal functions. Who owns the
// lock? This class? Does this class need a lock if it's not a multi-reader?
// (One doesn't exist today but presumably nothing prevents push + pop
// operations from happening on two different threads).
@@ -101,8 +101,9 @@ class PrefixedEntryRingBufferMulti {
// Same as PeekFront but includes the entry's preamble of optional user
// value and the varint of the data size.
- // TODO(pwbug/341): Move all other APIs to passing bytes_read by reference,
- // as it is required to determine the length populated in the span.
+ // TODO(b/235351847): Move all other APIs to passing bytes_read by
+ // reference, as it is required to determine the length populated in the
+ // span.
Status PeekFrontWithPreamble(span<std::byte> data,
uint32_t& user_preamble_out,
size_t& entry_bytes_read_out) const;
@@ -248,8 +249,8 @@ class PrefixedEntryRingBufferMulti {
const_iterator cbegin() { return begin(); }
const_iterator cend() { return end(); }
- // TODO(pwbug/340): Consider changing bool to an enum, to explicitly enumerate
- // what this variable means in clients.
+ // TODO(b/235351861): Consider changing bool to an enum, to explicitly
+ // enumerate what this variable means in clients.
PrefixedEntryRingBufferMulti(bool user_preamble = false)
: buffer_(nullptr),
buffer_bytes_(0),
diff --git a/pw_rpc/BUILD.bazel b/pw_rpc/BUILD.bazel
index df7a54dcd..5d4b3297d 100644
--- a/pw_rpc/BUILD.bazel
+++ b/pw_rpc/BUILD.bazel
@@ -323,7 +323,7 @@ pw_cc_test(
deps = [":internal_test_utils"],
)
-# TODO(pwbug/628): Add test_helpers_test when it is possible to use .options
+# TODO(b/234874064): Add test_helpers_test when it is possible to use .options
# in bazel build.
filegroup(
name = "test_helpers_test",
diff --git a/pw_rpc/nanopb/BUILD.bazel b/pw_rpc/nanopb/BUILD.bazel
index 0100d12bb..376a732b8 100644
--- a/pw_rpc/nanopb/BUILD.bazel
+++ b/pw_rpc/nanopb/BUILD.bazel
@@ -269,7 +269,7 @@ pw_cc_test(
],
)
-# TODO(pwbug/628): Requires nanopb options file support to compile.
+# TODO(b/234874064): Requires nanopb options file support to compile.
filegroup(
name = "echo_service_test",
srcs = ["echo_service_test.cc"],
diff --git a/pw_rpc/nanopb/public/pw_rpc/nanopb/client_testing.h b/pw_rpc/nanopb/public/pw_rpc/nanopb/client_testing.h
index 2832e1daf..df74524b6 100644
--- a/pw_rpc/nanopb/public/pw_rpc/nanopb/client_testing.h
+++ b/pw_rpc/nanopb/public/pw_rpc/nanopb/client_testing.h
@@ -24,7 +24,7 @@
namespace pw::rpc {
-// TODO(pwbug/477): Document the client testing APIs.
+// TODO(b/234878467): Document the client testing APIs.
// Sends packets to an RPC client as if it were a pw_rpc server. Accepts
// payloads as Nanopb structs.
diff --git a/pw_rpc/public/pw_rpc/channel.h b/pw_rpc/public/pw_rpc/channel.h
index 97a342aea..c215c778e 100644
--- a/pw_rpc/public/pw_rpc/channel.h
+++ b/pw_rpc/public/pw_rpc/channel.h
@@ -104,7 +104,7 @@ class Channel {
// Creates a dynamically assignable channel without a set ID or output.
constexpr Channel() : id_(kUnassignedChannelId), output_(nullptr) {}
- // TODO(pwbug/620): Remove the Configure and set_channel_output functions.
+ // TODO(b/234876441): Remove the Configure and set_channel_output functions.
// Users should call CloseChannel() / OpenChannel() to change a channel.
// This ensures calls are properly update and works consistently between
// static and dynamic channel allocation.
diff --git a/pw_rpc/pwpb/BUILD.bazel b/pw_rpc/pwpb/BUILD.bazel
index 6adc09d45..f0f55adad 100644
--- a/pw_rpc/pwpb/BUILD.bazel
+++ b/pw_rpc/pwpb/BUILD.bazel
@@ -268,7 +268,7 @@ pw_cc_test(
],
)
-# TODO(pwbug/628): Requires pwpb options file support to compile.
+# TODO(b/234874064): Requires pwpb options file support to compile.
filegroup(
name = "echo_service_test",
srcs = ["echo_service_test.cc"],
diff --git a/pw_rpc/pwpb/public/pw_rpc/pwpb/client_testing.h b/pw_rpc/pwpb/public/pw_rpc/pwpb/client_testing.h
index 72e4396f7..b0a8c8f7d 100644
--- a/pw_rpc/pwpb/public/pw_rpc/pwpb/client_testing.h
+++ b/pw_rpc/pwpb/public/pw_rpc/pwpb/client_testing.h
@@ -24,7 +24,7 @@
namespace pw::rpc {
-// TODO(pwbug/477): Document the client testing APIs.
+// TODO(b/234878467): Document the client testing APIs.
// Sends packets to an RPC client as if it were a pw_rpc server. Accepts
// payloads as pw_protobuf message structs.
diff --git a/pw_rpc/pwpb/public/pw_rpc/pwpb/internal/method.h b/pw_rpc/pwpb/public/pw_rpc/pwpb/internal/method.h
index adf7eae41..1a23b81fa 100644
--- a/pw_rpc/pwpb/public/pw_rpc/pwpb/internal/method.h
+++ b/pw_rpc/pwpb/public/pw_rpc/pwpb/internal/method.h
@@ -70,7 +70,7 @@ class PwpbMethod : public Method {
}
// Creates a PwpbMethod for a synchronous unary RPC.
- // TODO(pwbug/661): Find a way to reduce the number of monomorphized copies
+ // TODO(b/234874001): Find a way to reduce the number of monomorphized copies
// of this method.
template <auto kMethod>
static constexpr PwpbMethod SynchronousUnary(uint32_t id,
@@ -97,7 +97,7 @@ class PwpbMethod : public Method {
}
// Creates a PwpbMethod for an asynchronous unary RPC.
- // TODO(pwbug/661): Find a way to reduce the number of monomorphized copies
+ // TODO(b/234874001): Find a way to reduce the number of monomorphized copies
// of this method.
template <auto kMethod>
static constexpr PwpbMethod AsynchronousUnary(uint32_t id,
@@ -363,7 +363,7 @@ class PwpbMethod : public Method {
};
// MethodTraits specialization for a static synchronous unary method.
-// TODO(pwbug/658): Further qualify this (and nanopb) definition so that they
+// TODO(b/234874320): Further qualify this (and nanopb) definition so that they
// can co-exist in the same project.
template <typename Req, typename Res>
struct MethodTraits<PwpbSynchronousUnary<Req, Res>*> {
diff --git a/pw_rpc/py/pw_rpc/testing.py b/pw_rpc/py/pw_rpc/testing.py
index a9ab4d373..df62466fc 100644
--- a/pw_rpc/py/pw_rpc/testing.py
+++ b/pw_rpc/py/pw_rpc/testing.py
@@ -91,7 +91,7 @@ def execute_integration_test(server: str,
try:
server_process = subprocess.Popen([server, *common_args])
- # TODO(pwbug/508): Replace this delay with some sort of IPC.
+ # TODO(b/234879791): Replace this delay with some sort of IPC.
time.sleep(setup_time_s)
result = subprocess.run([client, *common_args]).returncode
diff --git a/pw_rpc/raw/public/pw_rpc/raw/client_testing.h b/pw_rpc/raw/public/pw_rpc/raw/client_testing.h
index 7b0cfd4f4..692d1fd8f 100644
--- a/pw_rpc/raw/public/pw_rpc/raw/client_testing.h
+++ b/pw_rpc/raw/public/pw_rpc/raw/client_testing.h
@@ -26,7 +26,7 @@
namespace pw::rpc {
-// TODO(pwbug/477): Document the client testing APIs.
+// TODO(b/234878467): Document the client testing APIs.
// Sends packets to an RPC client as if it were a pw_rpc server.
class FakeServer {
diff --git a/pw_software_update/bundled_update.proto b/pw_software_update/bundled_update.proto
index 697e3dd41..f2efe70b2 100644
--- a/pw_software_update/bundled_update.proto
+++ b/pw_software_update/bundled_update.proto
@@ -134,7 +134,7 @@ message StartRequest {
optional string bundle_filename = 1;
}
-// TODO(pwbug/478): Add documentation and details of the API contract.
+// TODO(b/235273688): Add documentation and details of the API contract.
service BundledUpdate {
// TODO: Offer GetCurrentManifest & GetStagedManifest() methods that leverage
// pw_transfer to upload the manifest off the device, to enable host logic.
diff --git a/pw_software_update/public/pw_software_update/bundled_update_backend.h b/pw_software_update/public/pw_software_update/bundled_update_backend.h
index babffeda5..27d051cae 100644
--- a/pw_software_update/public/pw_software_update/bundled_update_backend.h
+++ b/pw_software_update/public/pw_software_update/bundled_update_backend.h
@@ -25,7 +25,7 @@
namespace pw::software_update {
-// TODO(pwbug/478): update documentation for backend api contract
+// TODO(b/235273688): update documentation for backend api contract
class BundledUpdateBackend {
public:
virtual ~BundledUpdateBackend() = default;
diff --git a/pw_software_update/py/remote_sign_test.py b/pw_software_update/py/remote_sign_test.py
index f8727b15c..eeab948d9 100644
--- a/pw_software_update/py/remote_sign_test.py
+++ b/pw_software_update/py/remote_sign_test.py
@@ -71,7 +71,7 @@ FAKE_BUILDER_PUBLIC_KEY = textwrap.dedent("""\
# inclusive-language: enable
-# TODO(pwbug/653): Improve unit test coverage.
+# TODO(b/235240430): Improve unit test coverage.
class PathSigningTest(unittest.TestCase):
"""Tests the signing of bundles by path."""
@classmethod
diff --git a/pw_sync_baremetal/public/pw_sync_baremetal/interrupt_spin_lock_inline.h b/pw_sync_baremetal/public/pw_sync_baremetal/interrupt_spin_lock_inline.h
index 505cef396..70b286bc2 100644
--- a/pw_sync_baremetal/public/pw_sync_baremetal/interrupt_spin_lock_inline.h
+++ b/pw_sync_baremetal/public/pw_sync_baremetal/interrupt_spin_lock_inline.h
@@ -24,7 +24,7 @@ constexpr InterruptSpinLock::InterruptSpinLock() : native_type_() {}
inline void InterruptSpinLock::lock() { PW_ASSERT(try_lock()); }
inline bool InterruptSpinLock::try_lock() {
- // TODO(pwbug/303): Use the pw_interrupt API here to disable interrupts.
+ // TODO(b/235352722): Use the pw_interrupt API here to disable interrupts.
return !native_type_.test_and_set(std::memory_order_acquire);
}
diff --git a/pw_system/docs.rst b/pw_system/docs.rst
index 46799e905..a5214c644 100644
--- a/pw_system/docs.rst
+++ b/pw_system/docs.rst
@@ -134,7 +134,7 @@ being foundational infrastructure.
"PW_BOOT_FLASH_BEGIN=0x00000200",
"PW_BOOT_FLASH_SIZE=200K",
- # TODO(pwbug/219): Currently "pw_tokenizer/detokenize_test" requires at
+ # TODO(b/235348465): Currently "pw_tokenizer/detokenize_test" requires at
# least 6K bytes in heap when using pw_malloc_freelist. The heap size
# required for tests should be investigated.
"PW_BOOT_HEAP_SIZE=7K",
diff --git a/pw_system/work_queue.cc b/pw_system/work_queue.cc
index 1c7a05478..4c680e285 100644
--- a/pw_system/work_queue.cc
+++ b/pw_system/work_queue.cc
@@ -19,7 +19,7 @@
namespace pw::system {
-// TODO(pwbug/590): Consider switching this to a "NoDestroy" wrapped type to
+// TODO(b/234876895): Consider switching this to a "NoDestroy" wrapped type to
// allow the static destructor to be optimized out.
work_queue::WorkQueue& GetWorkQueue() {
static constexpr size_t kMaxWorkQueueEntries =
diff --git a/pw_thread/snapshot.cc b/pw_thread/snapshot.cc
index 4de0ee0b9..cfc36ce6f 100644
--- a/pw_thread/snapshot.cc
+++ b/pw_thread/snapshot.cc
@@ -32,7 +32,7 @@ namespace pw::thread {
Status SnapshotStack(const StackContext& stack,
Thread::StreamEncoder& encoder,
const ProcessThreadStackCallback& thread_stack_callback) {
- // TODO(pwbug/422): Add support for ascending stacks.
+ // TODO(b/234890430): Add support for ascending stacks.
encoder.WriteStackStartPointer(stack.stack_high_addr);
encoder.WriteStackEndPointer(stack.stack_low_addr);
encoder.WriteStackPointer(stack.stack_pointer);
diff --git a/pw_thread_freertos/snapshot.cc b/pw_thread_freertos/snapshot.cc
index d97a4bb4c..631eca93c 100644
--- a/pw_thread_freertos/snapshot.cc
+++ b/pw_thread_freertos/snapshot.cc
@@ -127,7 +127,7 @@ Status SnapshotThread(
CaptureThreadState(thread_state, encoder);
- // TODO(pwbug/422): Update this once we add support for ascending stacks.
+ // TODO(b/234890430): Update this once we add support for ascending stacks.
static_assert(portSTACK_GROWTH < 0, "Ascending stacks are not yet supported");
// If the thread is active, the stack pointer in the TCB is stale.
diff --git a/pw_tls_client/BUILD.gn b/pw_tls_client/BUILD.gn
index 6ea1406c5..4c223196b 100644
--- a/pw_tls_client/BUILD.gn
+++ b/pw_tls_client/BUILD.gn
@@ -110,7 +110,7 @@ pw_source_set("build_time") {
]
}
-# TODO(pwbug/396): Add a python target to generate source file from the
+# TODO(b/235290724): Add a python target to generate source file from the
# specified CRLSet file in `pw_tls_client_CRLSET_FILE`
pw_source_set("crlset") {
@@ -118,7 +118,7 @@ pw_source_set("crlset") {
public = [ "public/pw_tls_client/crlset.h" ]
public_deps = [ dir_pw_bytes ]
- # TODO(pwbug/396): Add sources generated from a CRLSet file to build.
+ # TODO(b/235290724): Add sources generated from a CRLSet file to build.
}
pw_source_set("test_server") {
diff --git a/pw_tokenizer/options.proto b/pw_tokenizer/options.proto
index bc0b87a6c..288a2dac6 100644
--- a/pw_tokenizer/options.proto
+++ b/pw_tokenizer/options.proto
@@ -29,7 +29,7 @@ enum Tokenization {
extend google.protobuf.FieldOptions {
// The field number was randomly selected from the reserved, internal use
// field numbers (50000-99999).
- // TODO(pwbug/393): Register with the Protobuf Global Extension Registry:
+ // TODO(b/234886465): Register with the Protobuf Global Extension Registry:
// https://github.com/protocolbuffers/protobuf/blob/HEAD/docs/options.md
Tokenization format = 78576;
}
diff --git a/pw_toolchain/generate_toolchain.gni b/pw_toolchain/generate_toolchain.gni
index 188be2e22..5ceb8543a 100644
--- a/pw_toolchain/generate_toolchain.gni
+++ b/pw_toolchain/generate_toolchain.gni
@@ -59,7 +59,7 @@ declare_args() {
# current_os: The OS of the toolchain. Defaults to "".
# Well known values include "win", "mac", "linux", "android", and "ios".
#
-# TODO(pwbug/333): This should be renamed to pw_generate_toolchain.
+# TODO(b/234891809): This should be renamed to pw_generate_toolchain.
template("generate_toolchain") {
assert(defined(invoker.defaults), "toolchain is missing 'defaults'")
diff --git a/pw_toolchain/host_clang/toolchain.cmake b/pw_toolchain/host_clang/toolchain.cmake
index 6010f36e5..f5dba8115 100644
--- a/pw_toolchain/host_clang/toolchain.cmake
+++ b/pw_toolchain/host_clang/toolchain.cmake
@@ -19,7 +19,7 @@ include(${CMAKE_CURRENT_LIST_DIR}/../../pw_build/pigweed.cmake)
set(CMAKE_C_COMPILER clang)
set(CMAKE_CXX_COMPILER clang++)
-# TODO(pwbug/606): set up this facade in CMake
+# TODO(b/235273743): set up this facade in CMake
# Use logging-based test output on host.
# pw_set_backend(pw_unit_test.main pw_unit_test.logging_main)
diff --git a/pw_toolchain/host_clang/toolchains.gni b/pw_toolchain/host_clang/toolchains.gni
index d9f9da76a..f68610dfd 100644
--- a/pw_toolchain/host_clang/toolchains.gni
+++ b/pw_toolchain/host_clang/toolchains.gni
@@ -47,7 +47,7 @@ _host_clang_toolchain = {
# Common default scope shared by all host Clang toolchains.
_defaults = {
- # TODO(pwbug/461) amend toolchain declaration process to
+ # TODO(b/234888755) amend toolchain declaration process to
# remove this hack.
default_configs = []
default_configs = [
diff --git a/pw_toolchain/host_gcc/toolchain.cmake b/pw_toolchain/host_gcc/toolchain.cmake
index b30fd670f..101346ba9 100644
--- a/pw_toolchain/host_gcc/toolchain.cmake
+++ b/pw_toolchain/host_gcc/toolchain.cmake
@@ -19,7 +19,7 @@ include(${CMAKE_CURRENT_LIST_DIR}/../../pw_build/pigweed.cmake)
set(CMAKE_C_COMPILER gcc)
set(CMAKE_CXX_COMPILER g++)
-# TODO(pwbug/606): set up this facade in CMake
+# TODO(b/235273743): set up this facade in CMake
# Use logging-based test output on host.
# pw_set_backend(pw_unit_test.main pw_unit_test.logging_main)
diff --git a/pw_trace_tokenized/trace_buffer_log_test.cc b/pw_trace_tokenized/trace_buffer_log_test.cc
index 20c9366be..328706cbd 100644
--- a/pw_trace_tokenized/trace_buffer_log_test.cc
+++ b/pw_trace_tokenized/trace_buffer_log_test.cc
@@ -20,7 +20,7 @@
#include "pw_trace/trace.h"
TEST(TokenizedTrace, DumpSmallBuffer) {
- // TODO(pwbug/266): This test only verifies that the dump function does not
+ // TODO(b/235283406): This test only verifies that the dump function does not
// crash, and requires manual inspection to confirm that the log output is
// correct. When there is support to mock and verify the calls to pw_log,
// these tests should be improved to validate the output.
@@ -32,7 +32,7 @@ TEST(TokenizedTrace, DumpSmallBuffer) {
}
TEST(TokenizedTrace, DumpLargeBuffer) {
- // TODO(pwbug/266): This test only verifies that the dump function does not
+ // TODO(b/235283406): This test only verifies that the dump function does not
// crash, and requires manual inspection to confirm that the log output is
// correct. When there is support to mock and verify the calls to pw_log,
// these tests should be improved to validate the output.
diff --git a/pw_transfer/BUILD.gn b/pw_transfer/BUILD.gn
index 1a5f3209b..9bd452626 100644
--- a/pw_transfer/BUILD.gn
+++ b/pw_transfer/BUILD.gn
@@ -148,7 +148,7 @@ pw_test_group("tests") {
":transfer_thread_test",
]
- # TODO(pwbug/441): Fix transfer tests on Windows and non-host builds.
+ # TODO(b/235345886): Fix transfer tests on Windows and non-host builds.
if (defined(pw_toolchain_SCOPE.is_host_toolchain) &&
pw_toolchain_SCOPE.is_host_toolchain && host_os != "win") {
tests += [
diff --git a/pw_unit_test/static_library_support_test.cc b/pw_unit_test/static_library_support_test.cc
index da7c414fb..cf134077c 100644
--- a/pw_unit_test/static_library_support_test.cc
+++ b/pw_unit_test/static_library_support_test.cc
@@ -41,7 +41,7 @@ class CheckThatTestsRanWhenDestructed {
}
} check_that_tests_ran;
-// TODO(pwbug/47): Convert this to a compilation failure test.
+// TODO(b/234882063): Convert this to a compilation failure test.
#if defined(PW_COMPILE_FAIL_TEST_FailsToLinkInvalidTestSuite)
PW_UNIT_TEST_LINK_FILE_CONTAINING_TEST(NotARealSuite, NotARealTest);
diff --git a/targets/emcraft_sf2_som/BUILD.gn b/targets/emcraft_sf2_som/BUILD.gn
index b375ebe37..d9c565b37 100644
--- a/targets/emcraft_sf2_som/BUILD.gn
+++ b/targets/emcraft_sf2_som/BUILD.gn
@@ -46,7 +46,7 @@ if (current_toolchain != default_toolchain) {
# (256K - Bootloader - InSystemProgrammer = 192K)
"PW_BOOT_CODE_SIZE=0x30000",
- # TODO(pwbug/219): Currently "pw_tokenizer/detokenize_test" requires at
+ # TODO(b/235348465): Currently "pw_tokenizer/detokenize_test" requires at
# least 6K bytes in heap when using pw_malloc_freelist. The heap size
# required for tests should be investigated.
"PW_BOOT_HEAP_SIZE=4M",
@@ -75,7 +75,7 @@ if (current_toolchain != default_toolchain) {
# (256K - Bootloader - InSystemProgrammer = 192K)
"PW_BOOT_FLASH_SIZE=0x30000",
- # TODO(pwbug/219): Currently "pw_tokenizer/detokenize_test" requires at
+ # TODO(b/235348465): Currently "pw_tokenizer/detokenize_test" requires at
# least 6K bytes in heap when using pw_malloc_freelist. The heap size
# required for tests should be investigated.
"PW_BOOT_HEAP_SIZE=4M",
diff --git a/targets/emcraft_sf2_som/emcraft_sf2_som_mddr_debug.ld b/targets/emcraft_sf2_som/emcraft_sf2_som_mddr_debug.ld
index 05e8615de..e529e1ca3 100644
--- a/targets/emcraft_sf2_som/emcraft_sf2_som_mddr_debug.ld
+++ b/targets/emcraft_sf2_som/emcraft_sf2_som_mddr_debug.ld
@@ -65,7 +65,7 @@ ENTRY(pw_boot_Entry)
MEMORY
{
- /* TODO(pwbug/57): Make it possible for projects to freely customize
+ /* TODO(b/234892223): Make it possible for projects to freely customize
* memory regions.
*/
diff --git a/targets/stm32f429i_disc1/target_toolchains.gni b/targets/stm32f429i_disc1/target_toolchains.gni
index 61012a741..a6657c1e9 100644
--- a/targets/stm32f429i_disc1/target_toolchains.gni
+++ b/targets/stm32f429i_disc1/target_toolchains.gni
@@ -62,7 +62,7 @@ _target_config = {
"PW_BOOT_FLASH_BEGIN=0x08000200",
"PW_BOOT_FLASH_SIZE=1024K",
- # TODO(pwbug/219): Currently "pw_tokenizer/detokenize_test" requires at
+ # TODO(b/235348465): Currently "pw_tokenizer/detokenize_test" requires at
# least 6K bytes in heap when using pw_malloc_freelist. The heap size
# required for tests should be investigated.
#
diff --git a/targets/stm32f429i_disc1_stm32cube/BUILD.gn b/targets/stm32f429i_disc1_stm32cube/BUILD.gn
index 818692857..c15325dd7 100644
--- a/targets/stm32f429i_disc1_stm32cube/BUILD.gn
+++ b/targets/stm32f429i_disc1_stm32cube/BUILD.gn
@@ -85,7 +85,7 @@ pw_system_target("stm32f429i_disc1_stm32cube") {
"PW_BOOT_FLASH_BEGIN=0x08000200",
"PW_BOOT_FLASH_SIZE=2048K",
- # TODO(pwbug/219): Currently "pw_tokenizer/detokenize_test" requires at
+ # TODO(b/235348465): Currently "pw_tokenizer/detokenize_test" requires at
# least 6K bytes in heap when using pw_malloc_freelist. The heap size
# required for tests should be investigated.
"PW_BOOT_HEAP_SIZE=7K",
diff --git a/pw_protobuf_compiler/pw_proto_library.bzl b/pw_protobuf_compiler/pw_proto_library.bzl
index 4a5de1534..8b343bc9e 100644
--- a/pw_protobuf_compiler/pw_proto_library.bzl
+++ b/pw_protobuf_compiler/pw_proto_library.bzl
@@ -22,7 +22,7 @@ of rules_proto_grpc. However, the version checked in here does not yet support,
In addition, nanopb proto files are not yet generated.
-TODO(pwbug/621): Close these gaps and start using this implementation.
+TODO(b/234873954): Close these gaps and start using this implementation.
# Overview of implementation
@@ -241,7 +241,7 @@ def _impl_pw_proto_library(ctx):
# in srcs. We don't perform layering_check in Pigweed, so this is not a big
# deal.
#
# TODO(pwbug/621): Tidy this up.
all_genfiles = []
for dep in ctx.attr.deps:
for f in dep[PwProtoInfo].genfiles:
@@ -241,7 +241,7 @@ def _impl_pw_proto_library(ctx):
# deal.
#
- # TODO(pwbug/621): Tidy this up.
+ # TODO(b/234873954): Tidy this up.
all_genfiles = []
for dep in ctx.attr.deps: